@@ -296,6 +296,7 @@ def command_install_tools(args):
     leave_files_after_installation = args.no_remove
     no_fsl = args.no_fsl
     install_only = args.install_only
+    build=args.build
     ### Clean install preparations
     if clean_install:
         logger("Removing temporary, existing packages (dtiplayground-tools only) directories ...")
@@ -337,25 +338,39 @@ def command_install_tools(args):
     srcdir = tempdir.joinpath('dtiplaygroundtools')
     info={}
     if not outputdir.exists():
-        if not srcdir.exists():
-            logger("Fetching source code ...")
-            fetch_dtiplaygroundtools = ["git","clone","https://github.com/niraluser/dtiplaygroundtools.git"]
-            subprocess.run(fetch_dtiplaygroundtools)
-            logger("Source codes downloaded")
-        
-        os.chdir(srcdir.joinpath('dockerfiles'))
-        build_command = ['./build.sh']
-        logger("Building software packages ... ")
-        subprocess.run(build_command)
-        tar_filename = srcdir.joinpath('dist/dtiplayground-tools.tar.gz')
-        untar_command = ['tar','xvfz',tar_filename.resolve().__str__(), '-C', rootdir.resolve().__str__()]
-        logger("Installing softwares to the output directory {}".format(outputdir.resolve().__str__()))
-        subprocess.run(untar_command)
-        ### read version info
-        info={}
-        info_fn = outputdir.joinpath('info.yml')
-        if info_fn.exists():
-            info = yaml.safe_load(open(info_fn,'r'))
+        if build:
+            if not srcdir.exists():
+                logger("Fetching source code ...")
+                fetch_dtiplaygroundtools = ["git","clone","https://github.com/niraluser/dtiplaygroundtools.git"]
+                subprocess.run(fetch_dtiplaygroundtools)
+                logger("Source codes downloaded")
+            
+            os.chdir(srcdir.joinpath('dockerfiles'))
+            build_command = ['./build.sh']
+            logger("Building software packages ... ")
+            subprocess.run(build_command)
+            tar_filename = srcdir.joinpath('dist/dtiplayground-tools.tar.gz')
+            untar_command = ['tar','xvfz',tar_filename.resolve().__str__(), '-C', rootdir.resolve().__str__()]
+            logger("Installing softwares to the output directory {}".format(outputdir.resolve().__str__()))
+            subprocess.run(untar_command)
+            ### read version info
+            info_fn = outputdir.joinpath('info.yml')
+            if info_fn.exists():
+                info = yaml.safe_load(open(info_fn,'r'))
+        else: # prebuilt package (default)
+            tar_filename = outputdir.joinpath('dtiplayground-tools.tar.gz')
+            if not tar_filename.exists():
+                remote_package = "https://github.com/NIRALUser/DTIPlaygroundTools/releases/download/v0.0.1/dtiplayground-tools.tar.gz"
+                fetch_package = ['wget',remote_package,'-P',outputdir.resolve().__str__()]
+                subprocess.run(fetch_package)
+            untar_command = ['tar','xvfz',tar_filename.resolve().__str__(), '-C', rootdir.resolve().__str__()]
+            logger("Installing softwares to the output directory {}".format(outputdir.resolve().__str__()))
+            subprocess.run(untar_command)
+            info_fn = outputdir.joinpath('info.yml')
+            if info_fn.exists():
+                info = yaml.safe_load(open(info_fn,'r'))
+            logger("Removing temporary files ...")
+            tar_filename.unlink()
 
     else:
         info = yaml.safe_load(open(outputdir.joinpath('info.yml'),'r'))
@@ -386,6 +401,7 @@ def command_init(args):
     tools_dir = None
     if args.tools_dir is not None:
         tools_dir = Path(args.tools_dir)
+
     user_module_dir=home_dir.parent.joinpath('modules/dmriprep').absolute()
     user_module_dir.mkdir(parents=True,exist_ok=True)
     user_tools_param_dir=home_dir.joinpath('parameters').absolute()
@@ -574,9 +590,10 @@ def command_remove_module(args):
 
 def parse_global_variables(global_vars: list):
     gv = {}
-    n_vars = int(len(global_vars)/2)
-    for i in range(n_vars):
-        gv[global_vars[i]]=global_vars[i+1]
+    if global_vars is not None:
+        n_vars = int(len(global_vars)/2)
+        for i in range(n_vars):
+            gv[global_vars[i*2]]=global_vars[i*2+1]
     return gv
 
 @after_initialized
@@ -605,7 +622,7 @@ def command_make_protocols(args):
             options['module_list']=None
     proto.makeDefaultProtocols(options['module_list'],template=template,options=options)
     outstr=yaml.dump(proto.getProtocols())
-    print(outstr)
+    # print(outstr)
     if options['output_path'] is not None:
         open(options['output_path'],'w').write(outstr)
         logger("Protocol file has been writte to : {}".format(options['output_path']),color.OK)
@@ -687,7 +704,6 @@ def get_args():
     
     ## init command
     parser_init=subparsers.add_parser('init',help='Initialize configurations')
-    parser_init.add_argument('--tools-dir', help="Initialize with specific tool directory", default=None)
     parser_init.set_defaults(func=command_init)
 
     ## update command
@@ -716,6 +732,7 @@ def get_args():
     parser_install_tools=subparsers.add_parser('install-tools',help='Install DTIPlaygroundTools')
     parser_install_tools.add_argument('-o','--output-dir', help="output directory", default="$HOME/.niral-dti")
     parser_install_tools.add_argument('-c','--clean-install', help="Remove existing files", default=False, action="store_true")
+    parser_install_tools.add_argument('-b','--build', help="Build DTIPlaygroundTools", default=False, action="store_true")
     parser_install_tools.add_argument('--no-remove', help="Do not remove source and build files after installation", default=False,action="store_true")
     parser_install_tools.add_argument('--no-fsl', help="Do not install FSL", default=False, action="store_true")
     parser_install_tools.add_argument('--install-only', help="Do not update current software paths", default=False, action="store_true")
@@ -758,7 +775,7 @@ def get_args():
     parser.add_argument('--no-log-timestamp',help='Remove timestamp in the log', default=False, action="store_true")
     parser.add_argument('--no-verbosity',help='Do not show any logs in the terminal', default=False, action="store_true")
     parser.add_argument('-v','--version', help="Show version", default=False,action="store_true")
-
+    parser.add_argument('--tools-dir', help="Initialize with specific tool directory", default=None)
     ## if no parameter is furnished, exit with printing help
     if len(sys.argv)==1:
         parser.print_help(sys.stderr)
